from logging import Logger
from typing import Callable
from typing import Optional
from typing import TypeVar

from aria.ops.object import Key
from aria.ops.object import Object


K8S_CHILD_OBJECT = TypeVar("K8S_CHILD_OBJECT", bound=Object)


def add_relationships(
    parents_by_key: dict[Key, Object],
    children: dict[Key, K8S_CHILD_OBJECT],
    logger: Logger,
    get_parent_key: Callable[[K8S_CHILD_OBJECT], Optional[Key]],
) -> None:
    for child in children.values():
        parent_key = get_parent_key(child)
        if parent_key is None:
            continue

        if parent_key is not None and parent_key in parents_by_key:
            logger.debug(f"Added '{child.get_key()}' to parent '{parent_key}'")
            parents_by_key[parent_key].add_child(child)
        else:
            logger.warning(f"Could not find a parent for child '{child.get_key()}'.")
